echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt

export KF6_PREFIX=/opt/kf6

# Required
[[ $(command -v checkXML6) == "" ]] && echo "Installing kde_framework" && extension --install kde_framework && echo "Finished kde_framework"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[ ! -f /lib/libvulkan.so ] && echo "Installing vulkan_loader" && extension --install vulkan_loader && echo "Finished vulkan_loader"
fi

if [ $BUILD_ALL == "false" ] && [ ! -d $KF6_PREFIX/lib/qml/org/kde/kirigamiaddons ]; then
	echo "kirigami_addons" 								>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "kirigami_addons" 								>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
